Module commands

Module commands 

CLI Subcommands

Contains modules that run the subcommands.

Modules

completions
ezcopy
Provide the cp subcommand
get
get_img
get from image
langx
Language Analysis and Transformations
mkdsk
modify
put
put_img
put to image
stat

Enums

CommandError
ItemType
Items of information that a user might want to get-from or put-to a disk image. The ItemType will affect how the CLI interprets the --file argument, i.e., as an ordinary file system path, a disk address, or a metadata key path.

Functions

get_fmt
process the pro argument, if it is a path retrieve the format from the file, if it is a JSON string process it directly.