pub fn create_disk_from_bytestream(disk_img_data: &Vec<u8>) -> Box<dyn A2Disk>
👎Deprecated since 0.2.0: will be modified to return an Option
Given a bytestream try to identify the type of disk image and create a disk object. N.b. this discards metadata and track layout details, only the high level data remains. This will also panic if the data cannot be interpreted.