Function a2kit::create_fs_from_file
source · pub fn create_fs_from_file(
img_path: &str
) -> Result<Box<dyn DiskFS>, Box<dyn Error>>Expand description
Calls create_fs_from_bytestream getting the bytes from a file.
The pathname must already be in the right format for the file system.
File extension will be used to restrict image types that are tried,
unless the extension is unknown, in which case all will be tried.