a2kit

Function create_img_from_bytestream

source
pub fn create_img_from_bytestream(
    disk_img_data: &Vec<u8>,
    maybe_ext: Option<&str>,
) -> Result<Box<dyn DiskImage>, Box<dyn Error>>
Given a bytestream return a disk image without any file system. Optional maybe_ext restricts the image types that will be tried based on file extension. N.b. the ordering for DSK types cannot always be determined without the file system.