Module types

Module types 

Structs

SequentialText
Structured representation of sequential text files on disk. CP/M terminates with 0x1a to the next 128-byte record boundary. For random access text use fs::Records instead.
TextConverter
Transforms between UTF8 and CP/M text. CP/M text is +ASCII with CRLF line separators, and 0x1A overall terminator. non-ASCII found in the CP/M text is put as ASCII null. non-ASCII found in a UTF8 string to convert is refused.

Enums

EntryType
Error
Enumerates CP/M errors. The Display trait will print the long message.
Ptr
Pointers to the various levels of CP/M disk structures. These just wrap integers and are supposed to help identify what is being indexed.

Constants

DELETED
Status byte for a deleted file, also fill value for unused blocks.
DIR_ENTRY_SIZE
Size of the directory entry in bytes, always 32
INVALID_CHARS
Characters forbidden from file names
LABEL
Status byte for a label
LOGICAL_EXTENT_SIZE
There is a subdivision of an extent, sometimes called a logical extent, which has a fixed size. See the EXM field in the disk parameter block.
MAX_LOGICAL_EXTENTS
Maximum number of logical extents in a file, array is indexed by major version number
RECORD_SIZE
Unit of data transfer in bytes as seen by the CP/M BDOS. This was the sector size on the original 8 inch disks.
TIMESTAMP
Status byte for a timestamp
USER_END
Largest possible user number plus one