SequentialText

Struct SequentialText 

pub struct SequentialText {
    pub header: Vec<u8>,
    pub text: Vec<u8>,
}
Structured representation of text files on disk. There is a page structure that we do not put into the structure. As a result the decoder must pass over nulls, the encoder must insert them.

Fields

header: Vec<u8>text: Vec<u8>