Module dot2mg

Module dot2mg 

Support for 2MG disk images

This format consists of a header followed by data in either DSK or NIB format. At the end of the data there can be a comment and creator information.

Structs

Dot2mg
Header

Functions

file_extensions