Imd

Struct Imd 

pub struct Imd { /* private fields */ }
There is a trivial compression scheme for the track data. Compression happens when the structure is flattened. Expansion happens when the structure is unflattened. Hence while we are working with the disk it is always expanded.

Implementations

Source

impl Imd

pub fn create(kind: DiskKind) -> Self