a2kit::img

Module woz1

source
Support for WOZ v1 disk images

This uses the nibble machinery in module disk525 to handle the bit streams. The DiskStruct trait is used to flatten and unflatten the wrapper structures. WOZ v1 cannot handle actual 3.5 inch disk tracks. Therefore the top level create function is set to panic if a 3.5 inch disk is requested. You can use WOZ v2 for 3.5 inch disks.

Structs

Functions