Minifier

Struct Minifier 

pub struct Minifier { /* private fields */ }
Handles minification of Applesoft BASIC

Implementations

Source

impl Minifier

pub fn new() -> Self

Create a new Minifier structure

pub fn set_flags(&mut self, flags: u64)

set the minification flags

pub fn set_level(&mut self, level: usize) -> u64

set minification level, 0 means no transformation, higher levels will set increasing numbers of flags, the flags are returned

pub fn set_external_refs(&mut self, externals: Vec<usize>)

pub fn minify(&mut self, program: &str) -> Result<String, Box<dyn Error>>

Try to reduce the size of a program. Flags determine the allowed transformations. An incremental level is the outward facing means of setting flags.