is_lang

Function is_lang 

pub fn is_lang(lang: Language, code: &str) -> bool
Test for the given language, returns false if there is any syntax error, does not always return true otherwise (additional criteria may be used). Warnings may be emitted if the results are ambiguous. Works for any language, provided it is line-oriented.