update_json_bool

Function update_json_bool 

pub fn update_json_bool(maybe_obj: &Value, key: &str, curr: &mut bool)
Try to update a named boolean from a serde Value presumed to be an object. If there is any error do not change the value.