update_json_f64

Function update_json_f64 

pub fn update_json_f64(maybe_obj: &Value, key: &str, curr: &mut f64)
Try to update a named float from a serde Value presumed to be an object. If there is any error do not change the value.