update_json_string_opt

Function update_json_string_opt 

pub fn update_json_string_opt(
    maybe_obj: &Value,
    key: &str,
    curr: &mut Option<String>,
)
Try to update a named optional string from a serde Value presumed to be an object. If there is any error do not change the value.