update_json_vec

Function update_json_vec 

pub fn update_json_vec(maybe_obj: &Value, key: &str, curr: &mut Vec<i64>)
Try to update a named list of integers from a serde Value presumed to be an object. If there is any error do not change the value.