Module integer

Module integer 

Integer BASIC analysis and transformations

This module is used by both the CLI and the language server. The Integer BASIC parser is provided by tree_sitter_integerbasic. The server compiles to a separate executable, its entry point is in src/bin/server-integerbasic/main.rs.

Modules

checkpoint
Integer BASIC checkpoint module.
completions
diagnostics
Integer diagnostics module.
hovers
renumber
Integer BASIC Renumber Module
semantic_tokens
settings
Parse settings string sent by any client.
tokenizer
Module containing the Integer BASIC tokenizer

Structs

Line
Information about a specific line label. The label itself is a key that maps to this information.
Symbols
Variable
Information about a specific variable. The name itself is a key that maps to this information. The key is always put in uppercase. There are 3 kinds: integers, integer arrays, and strings. A string is an array of characters. There are no arrays of strings. There are two namespaces:

Constants

ARRAY_OPEN
LEXPR
REXPR
SIMPLE_VAR_TYPES

Functions

bytes_to_escaped_string
Calls bytes_to_escaped_string_ex with escapes set to [138,141]
bytes_to_escaped_string_ex
Escape the bytes in some negative ASCII stringlike context. The escape value is not inverted. bytes are the bytes to escape, literal hex escapes will hex-escape the backslash (\x5c) offset is the index to start of context, one past the triggering byte terminator are characters that close the context Returns escaped string and index to terminator, terminator not included in string
lexpr_to_key
Calls var_to_key, going down to find the inner name if necessary @param node can be any LEXPR type @param row current row being analyzed @returns [normalized name,specific name,is_array,is_str,inner range], key name includes $ if a string
pass_through_subscript
Assuming we are on an opening parenthesis in a DIM statement, return the node of the corresponding closing parenthesis. This is needed because DIM variables are parsed as a flat sequence. @node the open_dim_str or open_dim_int node
var_to_key
Gather key information for a variable. @param node must be inner type, str_name or int_name @returns (normalized name,specific name,is_array,is_str), key name includes $ if a string