pass_through_subscript

Function pass_through_subscript 

pub fn pass_through_subscript<'a>(
    node: Node<'a>,
    line: &str,
) -> Option<Node<'a>>
Assuming we are on an opening parenthesis in a DIM statement, return the node of the corresponding closing parenthesis. This is needed because DIM variables are parsed as a flat sequence. @node the open_dim_str or open_dim_int node