WorkspaceScanner

Struct WorkspaceScanner 

pub struct WorkspaceScanner { /* private fields */ }

Implementations

Source

impl WorkspaceScanner

pub fn new() -> Self

pub fn update_doc(&mut self, doc: &Document)

Workspace scanner has its own copies that are not always up to date. This should be called when there is a document change notification. When there is a full rescan, call this with all checkpoints right after the gather.

pub fn get_workspace(&self) -> &Workspace

Borrow the workspace data

pub fn set_workspace(&mut self, ws: Workspace)

Set the workspace data, source is probably another analysis object

pub fn append_volatile_docs(&mut self, docs: Vec<Document>)

Add volatile documents to the workspace set, useful for piped documents

pub fn gather_docs( &mut self, dirs: &Vec<Uri>, max_files: usize, ) -> Result<(), Box<dyn Error>>

Buffer all documents matching *.s in any of dirs, up to maximum count max_files, searching at most MAX_DIRS directories, using at most MAX_DEPTH recursions, and ignoring IGNORE_DIRS.

pub fn scan(&mut self) -> Result<(), Box<dyn Error>>

Scan buffered documents for entries and includes. Assumes buffers are up to date.