macro_rules! getByte {
($root:ident,$typ:ident,$slf:ident.$($x:ident).+) => { ... };
}Expand description
Get a byte value from the image into a JSON object as a hex string.
getByte!(root:JsonValue,image_type:String,self.path.to.byte:u8)macro_rules! getByte {
($root:ident,$typ:ident,$slf:ident.$($x:ident).+) => { ... };
}Get a byte value from the image into a JSON object as a hex string.
getByte!(root:JsonValue,image_type:String,self.path.to.byte:u8)