Disk Parameter Block Module
This contains disk parameter blocks (DPB) for CP/M disks. There is no standard for storing a DPB on a CP/M disk; all we know is the BIOS must generate it somehow. As a result, we end up with the strategy of keeping a few likely DPB’s on hand to try heuristically.
Structs
- Disk
Parameter Block - The Disk Parameter Block (DPB) was introduced with CP/M v2.
This allows CP/M to work with a variety of disk formats.
The DPB was stored somewhere in the BIOS.
The parameters are interdependent in a complicated way, see
verifyfunction. Fields are public, but should be changed by hand only with caution.
Constants
- A2_525
- CPM1
- DSDD_
525_ OFF1 - This covers Kaypro 4 disks. Kaypro sector id’s are sequenced by cylinder, but we still regard SPT as the count of sectors on only one side. 32*(DRM+1) uses half the blocks mapped by AL0. The remainder are reserved OS blocks.
- NABU
- SSDD_3
- SSDD_
525_ OFF1 - This covers Kaypro II disks. 32*(DRM+1) uses half the blocks mapped by AL0. The remainder are reserved OS blocks.
- SSDD_
525_ OFF3 - This covers upgraded Osborne1 disks
- SSSD_
525 - This covers standard Osborne1 disks
- TRS80_
M2