CLI Subcommands
Contains modules that run the subcommands.
Modules
- completions
- ezcopy
- Provide the
cpsubcommand - get
- get_img
- get from image
- langx
- Language Analysis and Transformations
- mkdsk
- modify
- put
- put_img
- put to image
- stat
Enums
- Command
Error - Item
Type - Items of information that a user might want to get-from or put-to a disk image.
The
ItemTypewill affect how the CLI interprets the--fileargument, i.e., as an ordinary file system path, a disk address, or a metadata key path.
Functions
- get_fmt
- process the
proargument, if it is a path retrieve the format from the file, if it is a JSON string process it directly.