pub enum FileType {
Text = 0,
Integer = 1,
Applesoft = 2,
Binary = 4,
}Expand description
Enumerates the four basic file types, available conversions are:
- FileType to u8,u16,u32:
as u8etc. - u8,u16,u32 to FileType:
FileType::from_u8etc., (use FromPrimitive trait) - &str to FileType:
FileType::from_str, str can be a number or mnemonic - N.b. high bit may need to be masked out in some conversions
Variants