Language Module
Objects that want to walk a syntax tree can provide the Visit trait.
Such objects can take some action depending on the status of TreeCursor.
Language specific operations such as tokenization are in the submodules.
Modules
- Applesoft parsing module
- Integer BASIC parsing module
- Merlin assembly language parsing module
Structs
Enums
Traits
Functions
- Starting in some stringlike context defined by
ctx, where the trigger byte has already been consumed, escape the remaining bytes within that context. If there is a literal hex escape it is put as\x5CxHHwhere H is the hex. Return the escaped string and the index to the terminator. The terminator is not part of the returned string. - Get text of the node, source should be a single line. Panics if the source text does not include the node’s range.
- detect syntax errors in any language. Returns tuple with long and short result messages, or an error. N.b. there is extra behavior in the event either stdin or stdout are the console.
- Simple verify, returns an error if any issues