pub fn update_json_string(maybe_obj: &Value, key: &str, curr: &mut String)
Try to update a named string from a serde Value presumed to be an object. If there is any error do not change the value.
Value