pub fn update_json_vec_str(maybe_obj: &Value, key: &str, curr: &mut Vec<String>)
Try to update a named list of strings from a serde Value presumed to be an object. If there is any error do not change the value.
Value