Integer BASIC analysis and transformations
This module is used by both the CLI and the language server.
The Integer BASIC parser is provided by tree_sitter_integerbasic.
The server compiles to a separate executable, its entry point is in src/bin/server-integerbasic/main.rs.
Modules
- checkpoint
- Integer BASIC checkpoint module.
- completions
- diagnostics
- Integer diagnostics module.
- hovers
- renumber
- Integer BASIC Renumber Module
- semantic_
tokens - settings
- Parse settings string sent by any client.
- tokenizer
- Module containing the Integer BASIC tokenizer
Structs
- Line
- Information about a specific line label. The label itself is a key that maps to this information.
- Symbols
- Variable
- Information about a specific variable. The name itself is a key that maps to this information. The key is always put in uppercase. There are 3 kinds: integers, integer arrays, and strings. A string is an array of characters. There are no arrays of strings. There are two namespaces:
Constants
Functions
- bytes_
to_ escaped_ string - Calls
bytes_to_escaped_string_exwithescapesset to [138,141] - bytes_
to_ escaped_ string_ ex - Escape the bytes in some negative ASCII stringlike context. The escape value is not inverted.
bytesare the bytes to escape, literal hex escapes will hex-escape the backslash (\x5c)offsetis the index to start of context, one past the triggering byteterminatorare characters that close the context Returns escaped string and index to terminator, terminator not included in string - lexpr_
to_ key - Calls var_to_key, going down to find the inner name if necessary
@param node can be any LEXPR type
@param row current row being analyzed
@returns [normalized name,specific name,is_array,is_str,inner range], key name includes
$if a string - pass_
through_ subscript - Assuming we are on an opening parenthesis in a DIM statement,
return the node of the corresponding closing parenthesis.
This is needed because DIM variables are parsed as a flat sequence.
@node the
open_dim_stroropen_dim_intnode - var_
to_ key - Gather key information for a variable.
@param node must be inner type,
str_nameorint_name@returns (normalized name,specific name,is_array,is_str), key name includes$if a string