pub fn test_chain(node: &Node<'_>, source: &str) -> Option<String>Expand description
From a statement_print_str node see if this is a CHAIN pattern. Return None or Some(name) where name is the program being chained to. It would require extensive flow analysis to capture every possible CHAIN. We assume Integer BASIC is always running from DOS (no paths). The hook trigger can be a string variable or a literal ASCII 4