pub struct WorkspaceScanner { /* private fields */ }Implementations
Sourceimpl WorkspaceScanner
impl WorkspaceScanner
pub fn new() -> Self
Sourcepub fn update_doc(&mut self, doc: &Document)
pub fn update_doc(&mut self, doc: &Document)
Workspace scanner has its own copies that are not always up to date. This should be called when there is a document change notification. When there is a full rescan, call this with all checkpoints right after the gather.
Sourcepub fn get_workspace(&self) -> &Workspace
pub fn get_workspace(&self) -> &Workspace
Borrow the workspace data
Sourcepub fn set_workspace(&mut self, ws: Workspace)
pub fn set_workspace(&mut self, ws: Workspace)
Set the workspace data, source is probably another analysis object
Sourcepub fn append_volatile_docs(&mut self, docs: Vec<Document>)
pub fn append_volatile_docs(&mut self, docs: Vec<Document>)
Add volatile documents to the workspace set, useful for piped documents